require 'spec_helper'

describe SynapseClient::BankAccount do

  before(:each) do
    @customer = get_dummy_customer
  end

  describe "listing bank accounts" do
    it "should return an empty array when a customer has 0 bank accounts" do
      bank_accounts = @customer.bank_accounts

      expect(bank_accounts).to be_an(Array)
      expect(bank_accounts.count).to eq(0)
    end
  end

  describe "adding a bank account" do
    it "should successfully return the bank account." do
      bank_account = @customer.add_bank_account(dummy_add_bank_account_info)

      expect(bank_account).to be_a SynapseClient::BankAccount

      expect(bank_account.id).to be_a Fixnum
      expect(bank_account.account_number_string).to be_a String
      expect(bank_account.routing_number_string).to be_a String
      #expect(bank_account.bank_name).to be_a String
      expect(bank_account.nickname).to be_a String
      expect(bank_account.account_type).to be_a Fixnum
      expect(bank_account.account_class).to be_a Fixnum
    end

    it "should return an error message with failed bank add attemp." do
      bank_account = @customer.add_bank_account(dummy_wrong_add_bank_account_info)

      expect(bank_account).to be_a SynapseClient::APIOperations::Response

      expect(bank_account.successful?).to be false
      expect(bank_account.error_msg).not_to be nil
      expect(bank_account.error_msg).to be_a String
    end
  end

  describe "linking a bank account" do
    it "should successfully return an mfa." do
      mfa = @customer.link_bank_account(dummy_link_bank_account_info)

      expect(mfa).to be_a SynapseClient::MFA

      expect(mfa.type).to be_a String
      expect(mfa.bank_access_token).to be_a String
      expect(mfa.questions).to be_an Array
    end

    it "should successfully finish linking with an mfa." do
      mfa           = @customer.link_bank_account(dummy_link_bank_account_info)
      bank_accounts = @customer.finish_linking_bank_account(dummy_finish_linking_bank_account_info.merge({
        :bank_account_token => mfa.bank_access_token
      }))

      expect(bank_accounts).to be_a Array
      expect(bank_accounts.count).to be > 0

      bank_accounts.each do |ba|
        expect(ba.account_number_string).to be_a String
        expect(ba.routing_number_string).to be_a String
        expect(ba.bank_name).to be_a String
        expect(ba.nickname).to be_a String
        expect(ba.name_on_account).to be_a String
        expect(ba.account_type).to be_a Fixnum
        expect(ba.account_class).to be_a Fixnum
      end
    end
  end

end


